Message Metadata Model
=======================

This class repersents A Message's Metadata, Such as Message sender Id, Message timestamp, Message thread Id etc. This class only passed to some event listeners. 


Message Metadata
~~~~~~~~~~~~~~~~~

.. autoclass:: fbchat_muqit.MessageData
   :members:
   :undoc-members:
   :show-inheritance:

